@@ -257,7 +257,7 @@ def get_new_contact_template(supported_private_objects=[]):
         longest_key = max(supported_private_objects, key=len)
         for object in supported_private_objects:
             formatted_private_objects += convert_to_yaml(
-                    object, "", 12, len(longest_key)+1, True)
+                object, "", 12, len(longest_key)+1, True)
 
     # create template
     return dedent("""
@@ -275,17 +275,19 @@ def get_new_contact_template(supported_private_objects=[]):
         Last name  : 
         Suffix     : 
 
-        # person related information
-        #
-        # birthday
-        # Formats:
-        #   vcard 3.0 and 4.0: yyy-mm-dd or yyyy-mm-ddTHH:MM:SS
-        #   vcard 4.0 only: --mm-dd or text= string value
-        Birthday : 
         # nickname
         # may contain a string or a list of strings
         Nickname : 
 
+        # important dates
+        # Formats:
+        #   vcard 3.0 and 4.0: yyyy-mm-dd or yyyy-mm-ddTHH:MM:SS
+        #   vcard 4.0 only: --mm-dd or text= string value
+        # anniversary
+        Anniversary : 
+        # birthday
+        Birthday : 
+
         # organisation
         # format:
         #   Organisation : company
@@ -383,4 +385,6 @@ def get_new_contact_template(supported_private_objects=[]):
         #   Note : |
         #       line one
         #       line two
-        Note : """ % '\n'.join(formatted_private_objects))
+        Note : 
+        """ % '\n'.join(formatted_private_objects))
+
